Pycord
======

.. image:: https://img.shields.io/discord/1156255530797514802?label=discord&style=for-the-badge&logo=discord&color=5865F2&logoColor=white
   :target: https://discord.gg/fFAkd7CGkB
   :alt: Discord server invite
.. image:: https://img.shields.io/pypi/v/opredflag.svg?style=for-the-badge&logo=pypi&color=yellowgreen&logoColor=white
   :target: https://pypi.python.org/pypi/opredflag
   :alt: PyPI version info
.. image:: https://img.shields.io/pypi/pyversions/opredflag.svg?style=for-the-badge&logo=python&logoColor=white
   :target: https://pypi.python.org/pypi/opredflag
   :alt: PyPI supported Python versions
.. image:: https://img.shields.io/pypi/dm/opredflag?color=blueviolet&logo=pypi&logoColor=white&style=for-the-badge
   :target: https://pypi.python.org/pypi/opredflag
   :alt: PyPI downloads
.. image:: https://img.shields.io/github/v/release/BobDotCom/py-opredflag?include_prereleases&label=Latest%20Release&logo=github&sort=semver&style=for-the-badge&logoColor=white
   :target: https://github.com/BobDotCom/py-opredflag/releases
   :alt: Latest release

A package written in python with useful scripts for `Operation Red Flag <https://opredflag.com>`_.

Key Features
------------

- Intuitive Command-Line Interface (CLI)
- Easy-to-use Pythonic design
- Categorical design with dedicated sub-modules for different usages

Installing
----------

**Python 3.11 or higher is required**

To install the library, run the following command:

.. code:: sh

    # Linux/macOS
    python3 -m pip install -U opredflag

    # Windows
    py -3 -m pip install -U opredflag


To install the development version, do the following:

.. code:: sh

    $ git clone https://github.com/BobDotCom/py-opredflag
    $ cd pycord
    $ python3 -m pip install -U .

or if you do not want to clone the repository:

.. code:: sh

    # Linux/macOS
    python3 -m pip install git+https://github.com/BobDotCom/py-opredflag
    # Windows
    py -3 -m pip install git+https://github.com/BobDotCom/py-opredflag


Useful Links
------------

- `Documentation <https://opredflag.rtfd.io>`_
- `Our Official Discord Server <https://discord.gg/fFAkd7CGkB>`_
- `Official OPRF Server <https://discord.gg/M3YAZFtws9>`_
